# coding: utf-8

"""
    Nomad Envoy/Pilot

    This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import nomad_connectors_cli
from nomad_connectors_cli.models.order_product import OrderProduct  # noqa: E501
from nomad_connectors_cli.rest import ApiException


class TestOrderProduct(unittest.TestCase):
    """OrderProduct unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOrderProduct(self):
        """Test OrderProduct"""
        # FIXME: construct object with mandatory attributes with example values
        # model = nomad_connectors_cli.models.order_product.OrderProduct()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
